@@ -435,6 +435,9 @@ struct VADriverVTable
             VADriverContextP    ctx,
             VABufferID          buf_id          /* in */
         );
+
+        /** \brief Reserved bytes for future use, must be zero */
+        unsigned long reserved[64];
 };
 
 struct VADriverContext
@@ -524,7 +527,9 @@ struct VADriverContext
      */
     struct VADriverVTableVPP *vtable_vpp;
 
-    unsigned long reserved[42];         /* reserve for future add-ins, decrease the subscript accordingly */
+    char *override_driver_name;
+
+    unsigned long reserved[41];         /* reserve for future add-ins, decrease the subscript accordingly */
 };
 
 #define VA_DISPLAY_MAGIC 0x56414430 /* VAD0 */
@@ -551,6 +556,14 @@ struct VADisplayContext
     void *opaque; /* opaque for display extensions (e.g. GLX) */
     void *vatrace; /* opaque for VA trace context */
     void *vafool; /* opaque for VA fool context */
+
+    VAMessageCallback error_callback;
+    void *error_callback_user_context;
+    VAMessageCallback info_callback;
+    void *info_callback_user_context;
+
+    /** \brief Reserved bytes for future use, must be zero */
+    unsigned long reserved[32];
 };
 
 typedef VAStatus (*VADriverInit) (
